from fastapi import FastAPI, Request
from fastapi.templating import Jinja2Templates
from starlette.responses import RedirectResponse

import jinja2

from pnpdevice.config import config
import pnpdevice.discovery
import pnpdevice.relays

app = FastAPI(debug=config.DEBUG)
templates = Jinja2Templates(directory="templates")

@app.get("/")
def index():
	relays = request.app["relays"]
	return templates.TemplateResponse("index.template.html", {
		"relays": relays.relays_list(),
	})

@app.get("/relay/create")
def relay_create_get(request: Request):
	"Get the form to create a new relay."
	relays = request.app["relays"]
	pins = relays.pins_list()
	return templates.TemplateResponse("relay-create.template.html", {"pins": pins})

async def relay_create_post(request: Request, chip_and_number: str, name: str):
	"Create a new relay."
	chip, number = chip_and_number.partition("-")
	LOGGER.info("Creating relay %s %s with name %s", chip, number, name)
	return RedirectResponse(status_code=303, url="/")

async def status(request: Request):
	return html("Status")

def run(relays: pnpdevice.relays.Relays):
	"Run the embedded web server"
	app = web.Application()
	app["relays"] = relays
	aiohttp_jinja2.setup(app,
	  loader=jinja2.FileSystemLoader("templates"))
	app.on_startup.append(pnpdevice.discovery.handle)
	app.add_routes([web.get("/", index)])
	app.add_routes([web.get("/relay/create", relay_create_get)])
	app.add_routes([web.post("/relay/create", relay_create_post)])
	web.run_app(app)

